<!-- vale off -->
# Figure functions
API reference for all pre-defined [`CapturedCallable`][vizro.models.types.CapturedCallable] figure functions to be used in the
[`Figure`][vizro.models.Figure]. The [how-to guide on figures](../user-guides/figure.md) contains more information.

!!! note "Using figure functions in pure Dash app"
    Identical functions can also be used outside the Vizro framework in a pure Dash app by importing from the `vizro.figures.library` namespace:
    ```python
    from vizro.figures.library import kpi_card, kpi_card_reference
    ```

::: vizro.figures
    options:
      show_source: true

<!-- vale on -->
